@@ -2,7 +2,7 @@
  * GChemUtils GOffice component
  * gchempaint.h 
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,21 +20,21 @@
  * USA
  */
 
-#ifndef GOFFICE_GCHEMPAINT_PRIV_H
-#define GOFFICE_GCHEMPAINT_PRIV_H
+#ifndef GOFFICE_GCHEMUTILS_PRIV_H
+#define GOFFICE_GCHEMUTILS_PRIV_H
 
 #include "gchemutils.h"
-#include <gcu/application.h>
+#include <gogcuapp.h>
 #include <gcu/document.h>
+#include <gcu/window.h>
 
-using namespace gcu;
-
-typedef struct _GOGChemUtilsComponent
+struct _GOGChemUtilsComponent
 {
 	GOComponent parent;
 
-	Application *application;
-	Document *document;
+	GOGcuApplication *application;
+	gcu::Document *document;
+	gcu::Window *window; // TODO use a gcu::Window.
 };
 
 
