@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/calc/gchemcalc.cc 
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,9 +23,6 @@
  */
 
 #include "config.h"
-// FIXME: "the following lines should be removed for stable releases"
-#undef PACKAGE
-#define PACKAGE "gchemutils-unstable" 
 #include <gcu/application.h>
 #include <gcu/atom.h>
 #include <gcu/bond.h>
@@ -71,7 +68,9 @@
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-output-gio.h>
-#include <libgnomevfs/gnome-vfs.h>
+#ifdef GOFFICE_IS_0_6
+#	include <libgnomevfs/gnome-vfs-init.h>
+#endif
 #include <libxml/tree.h>
 #include <iostream>
 #include <cmath>
@@ -129,7 +128,7 @@ static Object* CreateDocument ()
 }
 
 GChemCalc::GChemCalc ():
-	Application ("gchemcalc-unstable"),
+	Application ("gchemcalc"),
 	formula ("")
 {
 	Object::AddType ("atom", CreateAtom, AtomType);
@@ -281,6 +280,11 @@ static void on_mail (GtkWidget *widget, gpointer data)
 	App->OnMail ();
 }
 
+static void on_live_assistance (GtkWidget *widget, gpointer dataw)
+{
+	App->OnLiveAssistance ();
+}
+
 static void on_bug (GtkWidget *widget, gpointer data)
 {
 	App->OnBug ();
@@ -288,10 +292,7 @@ static void on_bug (GtkWidget *widget, gpointer data)
 
 static void on_about_activate_url (GtkAboutDialog *about, const gchar *url, gpointer data)
 {
-	GnomeVFSResult error = gnome_vfs_url_show(url);
-	if (error != GNOME_VFS_OK) {
-		g_print("GnomeVFSResult while trying to launch URL in about dialog: error %u\n", error);
-	}
+	App->OnWeb (url);
 }
 
 static void on_about (GtkWidget *widget, void *data)
@@ -299,7 +300,7 @@ static void on_about (GtkWidget *widget, void *data)
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChemCalc is a simple calculator for chemists");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2005-2007 Jean Bréfort\n");
+	const gchar * copyright = _("Copyright © 2005-2008 Jean Bréfort");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -314,7 +315,7 @@ static void on_about (GtkWidget *widget, void *data)
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1307\n"
 		"USA";
 	
-	gtk_about_dialog_set_url_hook(on_about_activate_url, NULL, NULL);
+	gtk_about_dialog_set_url_hook (on_about_activate_url, NULL, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
@@ -625,6 +626,8 @@ static GtkActionEntry entries[] = {
 		  N_("View help for the Chemical Calculator"), G_CALLBACK (on_help) },
 	  { "Web", NULL, N_("Gnome Chemistry Utils on the _web"), NULL,
 		  N_("Browse the Gnome Chemistry Utils's web site"), G_CALLBACK (on_web) },
+	  { "LiveAssistance", NULL, N_("Live assistance"), NULL,
+		  N_("Open the Gnome Chemistry Utils IRC channel"), G_CALLBACK (on_live_assistance) },
 	  { "Mail", NULL, N_("_Ask a question"), NULL,
 		  N_("Ask a question about the Gnome Chemistry Utils"), G_CALLBACK (on_mail) },
 	  { "Bug", NULL, N_("Report _Bugs"), NULL,
@@ -671,39 +674,15 @@ static const char *ui_description =
 "    </menu>"
 "    <menu action='HelpMenu'>"
 "      <menuitem action='Help'/>"
-"      <placeholder name='mail'/>"
-"      <placeholder name='web'/>"
-"      <placeholder name='bug'/>"
+"      <menuitem action='Mail'/>"
+"      <menuitem action='Web'/>"
+"      <menuitem action='LiveAssistance'/>"
+"      <menuitem action='Bug'/>"
 "      <menuitem action='About'/>"
 "    </menu>"
 "  </menubar>"
 "</ui>";
 
-static const char *ui_mail_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='mail'>"
-"        <menuitem action='Mail'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
-static const char *ui_web_description =
-"<ui>"
-"  <menubar name='MainMenu'>"
-"    <menu action='HelpMenu'>"
-"      <placeholder name='web'>"
-"        <menuitem action='Web'/>"
-"      </placeholder>"
-"      <placeholder name='bug'>"
-"        <menuitem action='Bug'/>"
-"      </placeholder>"
-"    </menu>"
-"  </menubar>"
-"</ui>";
-
 gboolean cb_print_version (const gchar *option_name, const gchar *value, gpointer data, GError **error)
 {
 	char *version = g_strconcat (_("GChemCalc Calculator version: "), VERSION, NULL);
@@ -725,7 +704,12 @@ int main (int argc, char *argv[])
 	GError *error = NULL;
 	textdomain (GETTEXT_PACKAGE);
 	gtk_init (&argc, &argv);
-	gnome_vfs_init ();
+#ifdef GOFFICE_IS_0_6
+	if (!gnome_vfs_init ()) {
+		printf ("Could not initialize GnomeVFS\n");
+		return 1;
+	}
+#endif
 	if (argc > 1 && argv[1][0] == '-') {
 		context = g_option_context_new (_(" [formula]"));
 		g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
@@ -742,9 +726,8 @@ int main (int argc, char *argv[])
 		argv ++;
 	}
 
-// FIXME "the following line should be edited for stable releases"
 	if (argc > 1) {
-		cout << _("For usage see: gchemcalc-unstable [-?|--help]") << endl;
+		cout << _("For usage see: gchemcalc [-?|--help]") << endl;
 		return -1;
 	}
 
@@ -774,14 +757,6 @@ int main (int argc, char *argv[])
 		g_error_free (error);
 		exit (EXIT_FAILURE);
 	}
-	if (App->HasWebBrowser () && !gtk_ui_manager_add_ui_from_string (ui_manager, ui_web_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
-	if (App->HasMailAgent () && !gtk_ui_manager_add_ui_from_string (ui_manager, ui_mail_description, -1, &error)) {
-		g_message ("building menus failed: %s", error->message);
-		g_error_free (error);
-	}
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
 	gtk_box_reorder_child (GTK_BOX (vbox), bar, 0);
